@@ -31,7 +31,7 @@ URI_MAP = {
         "method": "GET"
     },
     "saas_download_deployment_package": {
-        "uri": "/files/{}",
+        "uri": "/files/d/{}",
         "method": "GET"
     },
     "saas_upload_report": {
