@@ -40,12 +40,23 @@ TF_MODEL_FORMATS = [ModelFormat.TF_KERAS_MODEL,
                     ModelFormat.TFLITE,
                     ModelFormat.CKPT]
 
-
+PYTORCH_MODEL_FORMATS = [ModelFormat.PT_NN_MODULE,
+                         ModelFormat.PTH,
+                         ModelFormat.TORCH_TRACED]
 class ModelDataType(Enum):
     NON_SPECIFIED = 0
     FP32 = 1
-    FP16 = 2
-
-    BF16 = 11
-
-    INT8 = 21
+    UINT8 = 2
+    INT8 = 3
+    UINT16 = 4
+    INT16 = 5
+    INT32 = 6
+    INT64 = 7
+    STR = 8
+    BOOL = 9
+    FP16 = 10
+    FP64 = 11
+    UINT32 = 12
+    UINT64 = 14
+    COMPLEX128 = 15
+    BFLOAT16 = 16
